percpu_area_base

Function percpu_area_base 

pub fn percpu_area_base(cpu_id: usize) -> usize
Returns the base address of the per-CPU data area for the given CPU.

Panics

Panics if the per-CPU area base address has not been set (i.e., init() or init_in_place() has not been called).

Concurrency

This function spins until initialization is complete if called during the initialization process.